{% load staticfiles sekizai_tags %}

{% addtoblock "css" %}<link href="https://api.mapbox.com/mapbox.js/v2.4.0/mapbox.css" rel="stylesheet" />{% endaddtoblock %}
{% addtoblock "js" %}<script src="https://api.mapbox.com/mapbox.js/v2.4.0/mapbox.js"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'djangocms_maps/js/mapbox.js' %}"></script>{% endaddtoblock %}
