{% load staticfiles sekizai_tags %}

{% addtoblock "css" %}<link href="https://js.api.here.com/v3/3.0/mapsjs-ui.css" rel="stylesheet" type="text/css" />{% endaddtoblock %}
{% addtoblock "js" %}<script src="https://js.api.here.com/v3/3.0/mapsjs-core.js" type="text/javascript" charset="UTF-8"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="https://js.api.here.com/v3/3.0/mapsjs-service.js" type="text/javascript" charset="UTF-8"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="https://js.api.here.com/v3/3.0/mapsjs-ui.js" type="text/javascript" charset="UTF-8"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="https://js.api.here.com/v3/3.0/mapsjs-mapevents.js" type="text/javascript" charset="UTF-8"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'djangocms_maps/js/here.js' %}"></script>{% endaddtoblock %}
