<div class="djangocms djangocms-maps plugin_maps">
    {% include "djangocms_maps/maps_title.html" %}
    <div class="djangocms-maps-container" id="djangocms-maps-{{ object.map_provider }}-{{ object.pk }}"
        data-id="{{ object.pk }}"
        data-title="{{ object.get_title }}"
        data-info_content="{{ object.content }}"
        data-address="{{ object.address }}, {{ object.zipcode }} {{ object.city }}"
        data-zoom="{{ object.zoom }}"
        data-scrollwheel="{{ object.scrollwheel|lower }}"
        data-double_click_zoom="{{ object.double_click_zoom|lower }}"
        data-draggable="{{ object.draggable|lower }}"
        data-keyboard_shortcuts="{{ object.keyboard_shortcuts|lower }}"
        data-pan_control="{{ object.pan_control|lower }}"
        data-zoom_control="{{ object.zoom_control|lower }}"
        data-street_view_control="{{ object.street_view_control|lower }}"
        data-lat="{% if object.lat %}{{ object.lat }}{% endif %}"
        data-lng="{% if object.lng %}{{ object.lng }}{% endif %}"
        data-show_infowindow="{{ object.info_window|lower }}"
        data-style="{{ object.style }}"
        data-api_key="{{ api_key }}"
        style="{% if object.width %}width: {{ object.width }}; {% endif %}{% if object.height %}height: {{ object.height }};{% endif %}">
    </div>
</div>
{% include "djangocms_maps/provider/"|add:object.map_provider|add:".html" %}
