{% load staticfiles sekizai_tags %}

{% addtoblock "js" %}<script src="//www.bing.com/api/maps/mapcontrol"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'djangocms_maps/js/bingmaps.js' %}"></script>{% endaddtoblock %}
