{% load staticfiles sekizai_tags %}

{% addtoblock "js" %}<script src="http://apijsv2.viamichelin.com/apijsv2/api/js?key={{ api_key }}&lang={{ LANGUAGE_CODE }}"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'djangocms_maps/js/viamichelin.js' %}"></script>{% endaddtoblock %}
